import { m as HighlighterCoreOptions, k as ShikiContext, H as HighlighterGeneric, n as BundledHighlighterOptions, L as LanguageInput, h as ThemeInput, C as CodeToHastOptions, R as Root, b as RequireKeys, c as CodeToThemedTokensOptions, T as ThemedToken, d as CodeToTokensWithThemesOptions } from './types/langs.mjs';
export { A as AnsiLanguage, e as Awaitable, B as BuiltinLanguage, a as BuiltinTheme, r as CodeOptionsMultipleThemes, q as CodeOptionsSingleTheme, s as CodeOptionsThemes, p as CodeToHastOptionsCommon, w as HastTransformers, x as HtmlRendererOptions, o as LanguageRegistration, t as LineOption, g as MaybeArray, M as MaybeGetter, f as MaybeModule, P as PlainTextLanguage, j as ResolveBundleKey, S as SpecialLanguage, i as StringLiteralUnion, v as ThemeRegistration, u as ThemeRegistrationRaw, z as ThemedTokenExplanation, y as ThemedTokenScopeExplanation, l as loadWasm } from './types/langs.mjs';

/**
* Get the minimal shiki context for rendering.
*/
declare function getShikiContext(options?: HighlighterCoreOptions): Promise<ShikiContext>;

type HighlighterCore = HighlighterGeneric<never, never>;
declare function getHighlighterCore(options?: HighlighterCoreOptions): Promise<HighlighterCore>;

type GetHighlighterFactory<L extends string, T extends string> = (options?: BundledHighlighterOptions<L, T>) => Promise<HighlighterGeneric<L, T>>;
/**
 * Create a `getHighlighter` function with bundled themes and languages.
 *
 * @param bundledLanguages
 * @param bundledThemes
 * @param ladWasm
 */
declare function createdBundledHighlighter<BundledLangs extends string, BundledThemes extends string>(bundledLanguages: Record<BundledLangs, LanguageInput>, bundledThemes: Record<BundledThemes, ThemeInput>, ladWasm: HighlighterCoreOptions['loadWasm']): GetHighlighterFactory<BundledLangs, BundledThemes>;
declare function createSingletonShorthands<L extends string, T extends string>(getHighlighter: GetHighlighterFactory<L, T>): {
    codeToHtml: (code: string, options: CodeToHastOptions<L, T>) => Promise<string>;
    codeToHast: (code: string, options: CodeToHastOptions<L, T>) => Promise<Root>;
    codeToThemedTokens: (code: string, options: RequireKeys<CodeToThemedTokensOptions<L, T>, 'theme' | 'lang'>) => Promise<ThemedToken[][]>;
    codeToTokensWithThemes: (code: string, options: RequireKeys<CodeToTokensWithThemesOptions<L, T>, 'themes' | 'lang'>) => Promise<[color: string, theme: string, tokens: ThemedToken[][]][]>;
};

export { BundledHighlighterOptions, CodeToHastOptions, CodeToThemedTokensOptions, CodeToTokensWithThemesOptions, type GetHighlighterFactory, type HighlighterCore, HighlighterCoreOptions, HighlighterGeneric, LanguageInput, RequireKeys, ShikiContext, ThemeInput, ThemedToken, createSingletonShorthands, createdBundledHighlighter, getHighlighterCore, getShikiContext };
